@@ -957,7 +957,7 @@ gnome_client_module_class_init (GnomeProgramClass *klass, const GnomeModuleInfo
                 g_param_spec_boolean (GNOME_CLIENT_PARAM_SM_CONNECT, NULL, NULL,
                                       sm_connect_default,
 				      (G_PARAM_READABLE | G_PARAM_WRITABLE |
-				       G_PARAM_CONSTRUCT_ONLY)));
+				       G_PARAM_CONSTRUCT)));
 }
 
 static void
@@ -983,6 +983,8 @@ gnome_client_module_info_get (void)
 	if (module_info.requirements == NULL) {
 		static GnomeModuleRequirement req[3];
 
+		bindtextdomain (GETTEXT_PACKAGE, GNOMEUILOCALEDIR);
+
 		req[0].required_version = "1.3.7";
 		req[0].module_info = gnome_gtk_module_info_get ();
 
