@@ -35,7 +35,6 @@
 #include "testgnome.h"
 #include "bomb.xpm"
 
-#ifdef FIXME
 static const gchar *authors[] = {
 	"Richard Hestilow",
 	"Federico Mena",
@@ -43,11 +42,10 @@ static const gchar *authors[] = {
 	"Havoc Pennington",
 	"Miguel de Icaza",
 	"Jonathan Blandford",
-	"Carlos Perell Marn",
+	"Carlos Perelló Marín",
 	"Martin Baulig",
 	NULL
 };
-#endif
 
 static void
 test_exit (TestGnomeApp *app)
@@ -88,16 +86,15 @@ verb_FileExit_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 static void
 verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
-#ifdef FIXME
+	const char *documentors[] = { "Documentor1", "Documentor2", NULL };
 	GtkWidget *about = gnome_about_new ("GNOME Test Program", VERSION,
 					    "(C) 1998-2001 The Free Software Foundation",
 					    "Program to display GNOME functions.",
 					    authors,
-					    NULL,
+					    documentors,
 					    NULL,
 					    NULL);
 	gtk_widget_show (about);
-#endif
 }
 
 static BonoboUIVerb verbs[] = {
@@ -119,13 +116,13 @@ quit_test (GtkWidget *caller, GdkEvent *event, TestGnomeApp *app)
 static TestGnomeApp *
 create_newwin(gboolean normal, gchar *appname, gchar *title)
 {
-        TestGnomeApp		*app;
+        TestGnomeApp *app;
 
 	app = g_new0 (TestGnomeApp, 1);
 	app->app = bonobo_window_new (appname, title);
 	if (!normal) {
-		gtk_signal_connect(GTK_OBJECT(app->app), "delete_event",
-				   GTK_SIGNAL_FUNC(quit_test), app);
+		g_signal_connect(app->app, "delete_event",
+				 G_CALLBACK(quit_test), app);
 	};
 	app->ui_container = bonobo_ui_engine_get_ui_container (
 		bonobo_window_get_ui_engine (BONOBO_WINDOW (app->app)));
@@ -134,12 +131,23 @@ create_newwin(gboolean normal, gchar *appname, gchar *title)
 	bonobo_ui_component_set_container (app->ui_component,
 					   BONOBO_OBJREF(app->ui_container),
 					   NULL);
-	bonobo_ui_util_set_ui (app->ui_component, GNOMEUIDATADIR, "testgnome.xml", appname);
+
+	bonobo_ui_util_set_ui (app->ui_component, "",
+			       GNOMEUISRCDIR "/testgnome.xml",
+			       appname, NULL);
+
 	bonobo_ui_component_add_verb_list_with_data (app->ui_component, verbs, app);
 	
 	return app;
 }
 
+
+static void
+color_set (GnomeColorPicker *cp, guint r, guint g, guint b, guint a)
+{
+	g_print ("Color set: %d %d %d %d\n", r, g, b, a);
+}
+
 /* Creates a color picker with the specified parameters */
 static void
 create_cp (GtkWidget *table, int dither, int use_alpha, int left, int right, int top, int bottom)
@@ -147,6 +155,9 @@ create_cp (GtkWidget *table, int dither, int use_alpha, int left, int right, int
 	GtkWidget *cp;
 
 	cp = gnome_color_picker_new ();
+	g_signal_connect (cp, "color_set",
+			  G_CALLBACK (color_set), NULL);
+
 	gnome_color_picker_set_dither (GNOME_COLOR_PICKER (cp), dither);
 	gnome_color_picker_set_use_alpha (GNOME_COLOR_PICKER (cp), use_alpha);
 	gnome_color_picker_set_d (GNOME_COLOR_PICKER (cp), 1.0, 0.0, 1.0, 0.5);
@@ -283,17 +294,17 @@ create_ditem_edit (void)
 	g_print("Dialog (main): %p\n", GNOME_DITEM_EDIT(dee)->icon_dialog);
 #endif
 
-	gtk_signal_connect(GTK_OBJECT(dee), "changed",
-			   GTK_SIGNAL_FUNC(ditem_changed_callback),
-			   NULL);
+	g_signal_connect(dee, "changed",
+			 G_CALLBACK(ditem_changed_callback),
+			 NULL);
 
-	gtk_signal_connect(GTK_OBJECT(dee), "icon_changed",
-			   GTK_SIGNAL_FUNC(ditem_icon_changed_callback),
-			   NULL);
+	g_signal_connect(dee, "icon_changed",
+			 G_CALLBACK(ditem_icon_changed_callback),
+			 NULL);
 
-	gtk_signal_connect(GTK_OBJECT(dee), "name_changed",
-			   GTK_SIGNAL_FUNC(ditem_name_changed_callback),
-			   NULL);
+	g_signal_connect(dee, "name_changed",
+			 G_CALLBACK(ditem_name_changed_callback),
+			 NULL);
 
 #ifdef GNOME_ENABLE_DEBUG
 	g_print("Dialog (main 2): %p\n", GNOME_DITEM_EDIT(dee)->icon_dialog);
@@ -323,7 +334,7 @@ typedef struct druid_data
 static gboolean
 simple_druid_next_callback (GnomeDruidPage *page, GnomeDruid *druid, GnomeDruidPage *next)
 {
-	gtk_object_set_data (GTK_OBJECT (next), "back", page);
+	g_object_set_data (G_OBJECT (next), "back", page);
 	gnome_druid_set_page (druid,
 	                      next);
 	return TRUE;
@@ -333,11 +344,11 @@ static gboolean
 complex_druid_next_callback (GnomeDruidPage *page, GnomeDruid *druid, druid_data *data)
 {
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->radio_button))) {
-		gtk_object_set_data (GTK_OBJECT (data->target_a), "back", page);
+		g_object_set_data (G_OBJECT (data->target_a), "back", page);
 		gnome_druid_set_page (druid,
 				      GNOME_DRUID_PAGE (data->target_a));
 	} else {
-		gtk_object_set_data (GTK_OBJECT (data->target_b), "back", page);
+		g_object_set_data (G_OBJECT (data->target_b), "back", page);
 		gnome_druid_set_page (druid,
 				      GNOME_DRUID_PAGE (data->target_b));
 	}
@@ -348,9 +359,9 @@ static gboolean
 druid_back_callback (GnomeDruidPage *page, GnomeDruid *druid, gpointer data)
 {
 	GtkWidget *back_page = NULL;
-	back_page = gtk_object_get_data (GTK_OBJECT (page), "back");
+	back_page = g_object_get_data (G_OBJECT (page), "back");
 	if (back_page) {
-		gtk_object_set_data (GTK_OBJECT (page), "back", NULL);
+		g_object_set_data (G_OBJECT (page), "back", NULL);
 		gnome_druid_set_page (druid,
 				      GNOME_DRUID_PAGE (back_page));
 		return TRUE;
@@ -435,8 +446,12 @@ create_druid(void)
 	data->radio_button = check_a;
 	data->target_a = page_b;
 	data->target_b = page_c;
-	gtk_signal_connect (GTK_OBJECT (page_a), "next", (GtkSignalFunc) complex_druid_next_callback, (gpointer) data);
-	gtk_signal_connect (GTK_OBJECT (page_a), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+	g_signal_connect (page_a, "next",
+			  G_CALLBACK (complex_druid_next_callback),
+			  data);
+	g_signal_connect (page_a, "back",
+			  G_CALLBACK (druid_back_callback),
+			  NULL);
 
 	/* page_b */
 	data = g_new (druid_data, 1);
@@ -452,46 +467,70 @@ create_druid(void)
 	data->radio_button = check_a;
 	data->target_a = page_d;
 	data->target_b = page_e;
-	gtk_signal_connect (GTK_OBJECT (page_b), "next", (GtkSignalFunc) complex_druid_next_callback, (gpointer) data);
-	gtk_signal_connect (GTK_OBJECT (page_b), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+	g_signal_connect (page_b, "next",
+			  G_CALLBACK (complex_druid_next_callback),
+			  data);
+	g_signal_connect (page_b, "back",
+			  G_CALLBACK (druid_back_callback),
+			  NULL);
 
 	/* page_c */
 	gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_c)->vbox),
 			    gtk_label_new ("This page will take you to page G\nYou don't have any say in the matter. (-:"),
 			    FALSE, FALSE, 0);
-	gtk_signal_connect (GTK_OBJECT (page_c), "next", (GtkSignalFunc) simple_druid_next_callback, (gpointer) page_g);
-	gtk_signal_connect (GTK_OBJECT (page_c), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+	g_signal_connect (page_c, "next",
+			  G_CALLBACK (simple_druid_next_callback),
+			  page_g);
+	g_signal_connect (page_c, "back",
+			  G_CALLBACK (druid_back_callback),
+			  NULL);
 
 	/* page_d */
 	gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_d)->vbox),
 			    gtk_label_new ("This page will take you to page F"),
 			    FALSE, FALSE, 0);
-	gtk_signal_connect (GTK_OBJECT (page_d), "next", (GtkSignalFunc) simple_druid_next_callback, (gpointer) page_f);
-	gtk_signal_connect (GTK_OBJECT (page_d), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+	g_signal_connect (page_d, "next",
+			  G_CALLBACK (simple_druid_next_callback),
+			  page_f);
+	g_signal_connect (page_d, "back",
+			  G_CALLBACK (druid_back_callback),
+			  NULL);
 
 	/* page_e */
 	gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_e)->vbox),
 			    gtk_label_new ("This page will take you to page G\n\nShe sells sea shells by the sea shore."),
 			    FALSE, FALSE, 0);
-	gtk_signal_connect (GTK_OBJECT (page_e), "next", (GtkSignalFunc) simple_druid_next_callback, (gpointer) page_g);
-	gtk_signal_connect (GTK_OBJECT (page_e), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+	g_signal_connect (page_e, "next",
+			  G_CALLBACK (simple_druid_next_callback),
+			  page_g);
+	g_signal_connect (page_e, "back",
+			  G_CALLBACK (druid_back_callback),
+			  NULL);
 
 	/* page_f */
 	gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_f)->vbox),
 			    gtk_label_new ("This is a second to last page.\nIt isn't as nice as page G.\n\nClick Next to go to the last page\n"),
 			    FALSE, FALSE, 0);
-	gtk_signal_connect (GTK_OBJECT (page_f), "next", (GtkSignalFunc) simple_druid_next_callback, (gpointer) page_finish);
-	gtk_signal_connect (GTK_OBJECT (page_f), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+	g_signal_connect (page_f, "next",
+			  G_CALLBACK (simple_druid_next_callback),
+			  page_finish);
+	g_signal_connect (page_f, "back",
+			  G_CALLBACK (druid_back_callback),
+			  NULL);
 
 	/* page_g */
 	gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_g)->vbox),
 			    gtk_label_new ("This is page G!!!!\n\nyay!!!!!!!"),
 			    FALSE, FALSE, 0);
-	gtk_signal_connect (GTK_OBJECT (page_g), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+	g_signal_connect (page_g, "back",
+			  G_CALLBACK (druid_back_callback),
+			  NULL);
 
 
 	/* page_finish */
-	gtk_signal_connect (GTK_OBJECT (page_finish), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+	g_signal_connect (page_finish, "back",
+			  G_CALLBACK (druid_back_callback),
+			  NULL);
 
 	/*Tie it together */
 	gtk_container_add (GTK_CONTAINER (window), druid);
@@ -529,7 +568,7 @@ create_entry(void)
 	GtkWidget *entry;
 
 	app = create_newwin(TRUE,"testGNOME","Entry");
-	entry = gnome_entry_new(NULL);
+	entry = gnome_entry_new("test-entry");
 	g_assert(entry != NULL);
 	bonobo_window_set_contents(BONOBO_WINDOW(app->app), entry);
 	gtk_widget_show(entry);
@@ -546,8 +585,8 @@ file_entry_update_files(GtkWidget *w, GnomeFileEntry *fentry)
 	char *p;
 	char *pp;
 
-	GtkLabel *l1 = gtk_object_get_data(GTK_OBJECT(w),"l1");
-	GtkLabel *l2 = gtk_object_get_data(GTK_OBJECT(w),"l2");
+	GtkLabel *l1 = g_object_get_data(G_OBJECT(w),"l1");
+	GtkLabel *l2 = g_object_get_data(G_OBJECT(w),"l2");
 
 	p = gnome_file_entry_get_full_path(fentry,FALSE);
 	pp = g_strconcat("File name: ",p,NULL);
@@ -596,56 +635,140 @@ create_file_entry(void)
 	gtk_box_pack_start(GTK_BOX(box),l2,FALSE,FALSE,0);
 
 	but = gtk_button_new_with_label("Update file labels");
-	gtk_object_set_data(GTK_OBJECT(but),"l1",l1);
-	gtk_object_set_data(GTK_OBJECT(but),"l2",l2);
-	gtk_signal_connect(GTK_OBJECT(but),"clicked",
-			   GTK_SIGNAL_FUNC(file_entry_update_files),
-			   entry);
+	g_object_set_data(G_OBJECT(but),"l1",l1);
+	g_object_set_data(G_OBJECT(but),"l2",l2);
+	g_signal_connect(but,"clicked",
+			 G_CALLBACK(file_entry_update_files),
+			 entry);
 	gtk_box_pack_start(GTK_BOX(box),but,FALSE,FALSE,0);
 
 	but = gtk_toggle_button_new_with_label("Make browse dialog modal");
-	gtk_signal_connect(GTK_OBJECT(but),"toggled",
-			   GTK_SIGNAL_FUNC(file_entry_modal_toggle),
-			   entry);
+	g_signal_connect(but,"toggled",
+			 G_CALLBACK(file_entry_modal_toggle),
+			 entry);
 	gtk_box_pack_start(GTK_BOX(box),but,FALSE,FALSE,0);
 
 	but = gtk_toggle_button_new_with_label("Directory only picker");
-	gtk_signal_connect(GTK_OBJECT(but),"toggled",
-			   GTK_SIGNAL_FUNC(file_entry_directory_toggle),
-			   entry);
+	g_signal_connect(but,"toggled",
+			 G_CALLBACK(file_entry_directory_toggle),
+			 entry);
 	gtk_box_pack_start(GTK_BOX(box),but,FALSE,FALSE,0);
 
 	bonobo_window_set_contents (BONOBO_WINDOW(app->app), box);
 	gtk_widget_show_all(app->app);
 }
 
+/*
+ * IconEntry
+ */
+static void
+icon_entry_changed (GnomeIconEntry *entry, GtkLabel *label)
+{
+	char *file = gnome_icon_entry_get_filename (entry);
+	g_print ("Entry changed, new icon: %s\n",
+		 file ? file : "Nothing selected");
+	g_free (file);
+}
+static void
+get_icon (GtkWidget *button, GnomeIconEntry *entry)
+{
+	GtkLabel *label = g_object_get_data (G_OBJECT (button), "label");
+	char *file = gnome_icon_entry_get_filename (entry);
+	gtk_label_set_text (label, file ? file : "Nothing selected");
+	g_free (file);
+}
+
+static void
+create_icon_entry(void)
+{
+	TestGnomeApp *app;
+	GtkWidget *vbox;
+	GtkWidget *button;
+	GtkWidget *label;
+	GtkWidget *entry;
+
+	app = create_newwin (TRUE, "testGNOME", "Icon Entry");
+
+	vbox = gtk_vbox_new (FALSE, 5);
+
+	entry = gnome_icon_entry_new ("Foo", "Icon");
+	gtk_box_pack_start (GTK_BOX (vbox), entry, TRUE, TRUE, 0);
+
+	button = gtk_button_new_with_label ("Update label below");
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+
+	label = gtk_label_new ("Nothing selected");
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+
+	g_signal_connect (entry, "changed",
+			  G_CALLBACK (icon_entry_changed), NULL);
+	g_signal_connect (button, "clicked",
+			  G_CALLBACK (get_icon), entry);
+	g_object_set_data (G_OBJECT (button), "label", label);
+
+	bonobo_window_set_contents (BONOBO_WINDOW (app->app), vbox);
+	gtk_widget_show_all (vbox);
+	gtk_widget_show (app->app);
+}
+
+/*
+ * PixmapEntry
+ */
+static void
+create_pixmap_entry(void)
+{
+	TestGnomeApp *app;
+	GtkWidget *entry;
+
+	app = create_newwin (TRUE, "testGNOME", "Pixmap Entry");
+
+	entry = gnome_pixmap_entry_new ("Foo", "Pixmap", TRUE);
+
+	bonobo_window_set_contents (BONOBO_WINDOW (app->app), entry);
+	gtk_widget_show (entry);
+	gtk_widget_show (app->app);
+}
+
+#if 0
+/*
+ * FontSelector
+ */
+static void
+create_font_selector (void)
+{
+	g_warning ("Font '%s'", gnome_font_select ());
+}
+#endif
+
+
 /*
  * FontPicker
  */
-#if 0
 static void
 cfp_ck_UseFont(GtkWidget *widget,GnomeFontPicker *gfp)
 {
 	gboolean show;
-	gint size;
 
-	show=!gfp->use_font_in_label;
-	size=gfp->use_font_in_label_size;
-
-	gnome_font_picker_fi_set_use_font_in_label(gfp,show,size);
+	g_object_get (G_OBJECT (gfp),
+		      "use-font-in-label", &show,
+		      NULL);
+	show = ! show;
 
+	g_object_set (G_OBJECT (gfp),
+		      "use-font-in-label", show,
+		      NULL);
 }
 
 static void
 cfp_sp_value_changed(GtkAdjustment *adj,GnomeFontPicker *gfp)
 {
-	gboolean show;
 	gint size;
 
-	show=gfp->use_font_in_label;
 	size=(gint)adj->value;
 
-	gnome_font_picker_fi_set_use_font_in_label(gfp,show,size);
+	g_object_set (G_OBJECT (gfp),
+		      "label-font-size", size,
+		      NULL);
 
 }
 
@@ -687,7 +810,7 @@ create_font_picker (void)
 	bonobo_window_set_contents(BONOBO_WINDOW(app->app),vbox);
 
 	/* Pixmap */
-	frPixmap=gtk_frame_new(_("Default Pixmap"));
+	frPixmap=gtk_frame_new("Default Pixmap");
 	gtk_box_pack_start(GTK_BOX(vbox),frPixmap,TRUE,TRUE,0);
 	vbox1=gtk_vbox_new(FALSE,FALSE);
 	gtk_container_add(GTK_CONTAINER(frPixmap),vbox1);
@@ -696,11 +819,12 @@ create_font_picker (void)
 	fontpicker1 = gnome_font_picker_new();
 	gtk_container_set_border_width(GTK_CONTAINER(fontpicker1),5);
 	gtk_box_pack_start(GTK_BOX(vbox1),fontpicker1,TRUE,TRUE,0);
-	lbPixmap=gtk_label_new(_("If you choose a font it will appear here"));
+	lbPixmap=gtk_label_new("If you choose a font it will appear here");
 	gtk_box_pack_start(GTK_BOX(vbox1),lbPixmap,TRUE,TRUE,5);
 
-	gtk_signal_connect(GTK_OBJECT(fontpicker1),"font_set",
-			   GTK_SIGNAL_FUNC(cfp_set_font),lbPixmap);
+	g_signal_connect(fontpicker1,"font_set",
+			 G_CALLBACK(cfp_set_font),
+			 lbPixmap);
 
 	/* Font_Info */
 	frFontInfo=gtk_frame_new("Font Info");
@@ -709,39 +833,43 @@ create_font_picker (void)
 	gtk_container_set_border_width(GTK_CONTAINER(vbox2),5);
 	gtk_container_add(GTK_CONTAINER(frFontInfo),vbox2);
 
+	fontpicker2 = gnome_font_picker_new();
+
 	/* GnomeFontPicker with fontinfo */
 	hbox1=gtk_hbox_new(FALSE,5);
 	gtk_box_pack_start(GTK_BOX(vbox2),hbox1,FALSE,FALSE,0);
-	ckUseFont=gtk_check_button_new_with_label(_("Use Font in button with size"));
+	ckUseFont=gtk_check_button_new_with_label("Use Font in button with size");
 	gtk_box_pack_start(GTK_BOX(hbox1),ckUseFont,TRUE,TRUE,0);
 
 	adj=GTK_ADJUSTMENT(gtk_adjustment_new(14,5,150,1,1,1));
+	g_signal_connect (adj, "value_changed",
+			  G_CALLBACK (cfp_sp_value_changed),
+			  fontpicker2);
 	spUseFont=gtk_spin_button_new(adj,1,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spUseFont,FALSE,FALSE,0);
+	g_object_set_data (G_OBJECT (fontpicker2), "spUseFont", spUseFont);
 
-	ckShowSize=gtk_check_button_new_with_label(_("Show font size"));
+	g_signal_connect (ckUseFont, "toggled",
+			  G_CALLBACK (cfp_ck_UseFont),
+			  fontpicker2);
+
+	ckShowSize=gtk_check_button_new_with_label("Show font size");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ckShowSize),TRUE);
 	gtk_box_pack_start(GTK_BOX(vbox2),ckShowSize,FALSE,FALSE,5);
 
-	fontpicker2 = gnome_font_picker_new();
+	g_signal_connect (ckShowSize, "toggled",
+			  G_CALLBACK (cfp_ck_ShowSize),
+			  fontpicker2);
+
 	gnome_font_picker_set_mode(GNOME_FONT_PICKER(fontpicker2),GNOME_FONT_PICKER_MODE_FONT_INFO);
 	gtk_box_pack_start(GTK_BOX(vbox2),fontpicker2,TRUE,TRUE,0);
 
-	gtk_signal_connect(GTK_OBJECT(ckUseFont),"toggled",
-			   (GtkSignalFunc)cfp_ck_UseFont,fontpicker2);
-
-	gtk_signal_connect(GTK_OBJECT(ckShowSize),"toggled",
-			   (GtkSignalFunc)cfp_ck_ShowSize,fontpicker2);
-
-	gtk_signal_connect(GTK_OBJECT(adj),"value_changed",
-			   (GtkSignalFunc)cfp_sp_value_changed,fontpicker2);
-
-	lbFontInfo=gtk_label_new(_("If you choose a font it will appear here"));
+	lbFontInfo=gtk_label_new("If you choose a font it will appear here");
 	gtk_box_pack_start(GTK_BOX(vbox2),lbFontInfo,TRUE,TRUE,5);
 
 
-	gtk_signal_connect(GTK_OBJECT(fontpicker2),"font_set",
-			   GTK_SIGNAL_FUNC(cfp_set_font),lbFontInfo);
+	g_signal_connect(fontpicker2,"font_set",
+			 G_CALLBACK(cfp_set_font),lbFontInfo);
 
 
 	/* User Widget */
@@ -755,24 +883,26 @@ create_font_picker (void)
 	gnome_font_picker_set_mode(GNOME_FONT_PICKER(fontpicker3),GNOME_FONT_PICKER_MODE_USER_WIDGET);
 
 	hbox3=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox3),gnome_stock_new_with_icon(GNOME_STOCK_PIXMAP_SPELLCHECK),
+	gtk_box_pack_start(GTK_BOX(hbox3),gtk_image_new_from_stock
+                           (GNOME_STOCK_PIXMAP_SPELLCHECK, GTK_ICON_SIZE_BUTTON),
 			   FALSE,FALSE,5);
-	gtk_box_pack_start(GTK_BOX(hbox3),gtk_label_new(_("This is an hbox with pixmap and text")),
+	gtk_box_pack_start(GTK_BOX(hbox3),gtk_label_new("This is an hbox with pixmap and text"),
 			   FALSE,FALSE,5);
 	gnome_font_picker_uw_set_widget(GNOME_FONT_PICKER(fontpicker3),hbox3);
 	gtk_container_set_border_width(GTK_CONTAINER(fontpicker3),5);
 	gtk_box_pack_start(GTK_BOX(vbox3),fontpicker3,TRUE,TRUE,0);
 
-	lbUser=gtk_label_new(_("If you choose a font it will appear here"));
+	lbUser=gtk_label_new("If you choose a font it will appear here");
 	gtk_box_pack_start(GTK_BOX(vbox3),lbUser,TRUE,TRUE,5);
 
-	gtk_signal_connect(GTK_OBJECT(fontpicker3),"font_set",
-			   GTK_SIGNAL_FUNC(cfp_set_font),lbUser);
+	g_signal_connect(fontpicker3,"font_set",
+			 G_CALLBACK(cfp_set_font),lbUser);
 
 	gtk_widget_show_all(app->app);
 
 }
-#endif
+
+
 /*
  * HRef
  */
@@ -780,9 +910,9 @@ create_font_picker (void)
 static void
 href_cb(GtkObject *button)
 {
-	GtkWidget *href = gtk_object_get_data(button, "href");
-	GtkWidget *url_ent = gtk_object_get_data(button, "url");
-	GtkWidget *label_ent = gtk_object_get_data(button, "label");
+	GtkWidget *href = g_object_get_data (G_OBJECT (button), "href");
+	GtkWidget *url_ent = g_object_get_data (G_OBJECT (button), "url");
+	GtkWidget *label_ent = g_object_get_data (G_OBJECT (button), "label");
 	gchar *url, *text;
 
 	url = gtk_editable_get_chars (GTK_EDITABLE(url_ent), 0, -1);
@@ -823,11 +953,11 @@ create_href(void)
 	gtk_box_pack_start (GTK_BOX(vbox), ent2, TRUE, TRUE, 0);
 
 	wid = gtk_button_new_with_label ("set href props");
-	gtk_object_set_data (GTK_OBJECT(wid), "href", href);
-	gtk_object_set_data (GTK_OBJECT(wid), "url", ent1);
-	gtk_object_set_data (GTK_OBJECT(wid), "label", ent2);
-	gtk_signal_connect (GTK_OBJECT(wid), "clicked",
-			    GTK_SIGNAL_FUNC(href_cb), NULL);
+	g_object_set_data (G_OBJECT(wid), "href", href);
+	g_object_set_data (G_OBJECT(wid), "url", ent1);
+	g_object_set_data (G_OBJECT(wid), "label", ent2);
+	g_signal_connect (wid, "clicked",
+			  G_CALLBACK(href_cb), NULL);
 	gtk_box_pack_start (GTK_BOX(vbox), wid, TRUE, TRUE, 0);
 
 	gtk_widget_show_all(app->app);
@@ -875,21 +1005,20 @@ create_icon_list(void)
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
 	bonobo_window_set_contents (BONOBO_WINDOW (app->app), sw);
-	gtk_widget_set_usize (sw, 430, 300);
+	gtk_widget_set_size_request (sw, 430, 300);
 	gtk_widget_show (sw);
 
-	iconlist = gnome_icon_list_new (80, GNOME_ICON_LIST_IS_EDITABLE);
+	iconlist = gnome_icon_list_new (80, NULL, GNOME_ICON_LIST_IS_EDITABLE);
 	gtk_container_add (GTK_CONTAINER (sw), iconlist);
-	gtk_signal_connect (GTK_OBJECT (iconlist), "select_icon",
-			    GTK_SIGNAL_FUNC (select_icon),
-			    NULL);
-	gtk_signal_connect (GTK_OBJECT (iconlist), "unselect_icon",
-			    GTK_SIGNAL_FUNC (unselect_icon),
-			    NULL);
+	g_signal_connect (iconlist, "select_icon",
+			  G_CALLBACK (select_icon),
+			  NULL);
+	g_signal_connect (iconlist, "unselect_icon",
+			  G_CALLBACK (unselect_icon),
+			  NULL);
 
 	GTK_WIDGET_SET_FLAGS(iconlist, GTK_CAN_FOCUS);
 	pix = gdk_pixbuf_new_from_xpm_data ((const gchar **)bomb_xpm);
-/*	gdk_imlib_render (pix, pix->rgb_width, pix->rgb_height);*/
 
 	gtk_widget_grab_focus (iconlist);
 
@@ -901,6 +1030,7 @@ create_icon_list(void)
 		gnome_icon_list_append_pixbuf (GNOME_ICON_LIST(iconlist), pix, "bomb.xpm", "LaLa");
 	}
 
+	gnome_icon_list_append (GNOME_ICON_LIST(iconlist), "non-existant.png", "No Icon");
 
 	gnome_icon_list_set_selection_mode (GNOME_ICON_LIST (iconlist), GTK_SELECTION_EXTENDED);
 	gnome_icon_list_thaw (GNOME_ICON_LIST (iconlist));
@@ -908,6 +1038,385 @@ create_icon_list(void)
 	gtk_widget_show(app->app);
 }
 
+
+/* Used as a callback for menu items in the GnomeAppHelper test; just prints the string contents of
+ * the data pointer.
+ */
+static void
+item_activated (GtkWidget *widget, gpointer data)
+{
+	printf ("%s activated\n", (char *) data);
+}
+
+/* Menu definitions for the GnomeAppHelper test */
+
+static GnomeUIInfo helper_file_menu[] = {
+	{ GNOME_APP_UI_ITEM, "_New", "Create a new file", item_activated, "file/new", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 'n', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, "_Open...", "Open an existing file", item_activated, "file/open", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 'o', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, "_Save", "Save the current file", item_activated, "file/save", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 's', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, "Save _as...", "Save the current file with a new name", item_activated, "file/save as", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE_AS, 0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	{ GNOME_APP_UI_ITEM, "_Print...", "Print the current file", item_activated, "file/print", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PRINT, 'p', GDK_CONTROL_MASK, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	GNOMEUIINFO_MENU_CLOSE_ITEM(item_activated, "file/close"),
+	GNOMEUIINFO_MENU_EXIT_ITEM(item_activated, "file/exit"),
+
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo helper_edit_menu[] = {
+	{ GNOME_APP_UI_ITEM, "_Undo", "Undo the last operation", item_activated, "edit/undo", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_UNDO, 'z', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, "_Redo", "Redo the last undo-ed operation", item_activated, "edit/redo", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REDO, 0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	{ GNOME_APP_UI_ITEM, "Cu_t", "Cut the selection to the clipboard", item_activated, "edit/cut", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CUT, 'x', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, "_Copy", "Copy the selection to the clipboard", item_activated, "edit/copy", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_COPY, 'c', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, "_Paste", "Paste the contents of the clipboard", item_activated, "edit/paste", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PASTE, 'v', GDK_CONTROL_MASK, NULL },
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo helper_style_radio_items[] = {
+	{ GNOME_APP_UI_ITEM, "_10 points", NULL, item_activated, "style/10 points", NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "_20 points", NULL, item_activated, "style/20 points", NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "_30 points", NULL, item_activated, "style/30 points", NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "_40 points", NULL, item_activated, "style/40 points", NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo helper_style_menu[] = {
+	{ GNOME_APP_UI_TOGGLEITEM, "_Bold", "Make the selection bold", item_activated, "style/bold", NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_TOGGLEITEM, "_Italic", "Make the selection italic", item_activated, "style/bold", NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	GNOMEUIINFO_RADIOLIST (helper_style_radio_items),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo helper_help_menu[] = {
+	{ GNOME_APP_UI_ITEM, "_About...", "Displays information about the program", item_activated, "help/about", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL },
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo helper_main_menu[] = {
+	{ GNOME_APP_UI_SUBTREE, "_File", "File operations", helper_file_menu, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_SUBTREE, "_Edit", "Editing commands", helper_edit_menu, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_SUBTREE, "_Style", "Style settings", helper_style_menu, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_SUBTREE, "_Help", "Help on the program", helper_help_menu, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	GNOMEUIINFO_END
+};
+
+/* Toolbar definition for the GnomeAppHelper test */
+
+static GnomeUIInfo helper_toolbar_radio_items[] = {
+	{ GNOME_APP_UI_ITEM, "Red", "Set red color", item_activated, "toolbar/red", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_BOOK_RED, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Green", "Set green color", item_activated, "toolbar/green", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_BOOK_GREEN, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Blue", "Set blue color", item_activated, "toolbar/blue", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_BOOK_BLUE, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Yellow", "Set yellow color", item_activated, "toolbar/yellow", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_BOOK_YELLOW, 0, 0, NULL },
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo helper_toolbar[] = {
+	{ GNOME_APP_UI_ITEM, "New", "Create a new file", item_activated, "toolbar/new", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_NEW, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Open", "Open an existing file", item_activated, "toolbar/open", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_OPEN, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Save", "Save the current file", item_activated, "toolbar/save", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_SAVE, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Print", "Print the current file", item_activated, "toolbar/print", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_PRINT, 0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	{ GNOME_APP_UI_ITEM, "Undo", "Undo the last operation", item_activated, "toolbar/undo", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_UNDO, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Redo", "Redo the last undo-ed operation", item_activated, "toolbar/redo", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_REDO, 0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	{ GNOME_APP_UI_ITEM, "Cut", "Cut the selection to the clipboard", item_activated, "toolbar/cut", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_CUT, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Copy", "Copy the selection to the clipboard", item_activated, "toolbar/copy", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_COPY, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Paste", "Paste the contents of the clipboard", item_activated, "toolbar/paste", NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_PASTE, 0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	GNOMEUIINFO_RADIOLIST (helper_toolbar_radio_items),
+	GNOMEUIINFO_END
+};
+
+/* These three functions insert some silly text in the GtkEntry specified in the user data */
+
+static void
+insert_red (GtkWidget *widget, gpointer data)
+{
+	int pos;
+	GtkWidget *entry;
+
+	g_print ("in callback, data is: %p\n", data);
+	
+	entry = GTK_WIDGET (data);
+
+	pos = gtk_editable_get_position (GTK_EDITABLE (entry));
+	gtk_editable_insert_text (GTK_EDITABLE (entry), "red book ", strlen ("red book "), &pos);
+}
+
+static void
+insert_green (GtkWidget *widget, gpointer data)
+{
+	int pos;
+	GtkWidget *entry;
+
+	entry = GTK_WIDGET (data);
+
+	pos = gtk_editable_get_position (GTK_EDITABLE (entry));
+	gtk_editable_insert_text (GTK_EDITABLE (entry), "green book ", strlen ("green book "), &pos);
+}
+
+static void
+insert_blue (GtkWidget *widget, gpointer data)
+{
+	int pos;
+	GtkWidget *entry;
+
+	entry = GTK_WIDGET (data);
+
+	pos = gtk_editable_get_position (GTK_EDITABLE (entry));
+	gtk_editable_insert_text (GTK_EDITABLE (entry), "blue book ", strlen ("blue book "), &pos);
+}
+
+/* Shared popup menu definition for the GnomeAppHelper test */
+
+static GnomeUIInfo helper_shared_popup_dup[] = {
+	{ GNOME_APP_UI_ITEM, "Insert a _red book", NULL, insert_red, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_RED, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Insert a _green book", NULL, insert_green, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_GREEN, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Insert a _blue book", NULL, insert_blue, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_BLUE, 0, 0, NULL },
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo helper_shared_popup[] = {
+	{ GNOME_APP_UI_ITEM, "Insert a _red book", NULL, insert_red, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_RED, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Insert a _green book", NULL, insert_green, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_GREEN, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Insert a _blue book", NULL, insert_blue, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_BLUE, 0, 0, NULL },
+        GNOMEUIINFO_SUBTREE("Subtree", helper_shared_popup_dup),
+	GNOMEUIINFO_END
+};
+
+/* These function change the fill color of the canvas item specified in the user data */
+
+static void
+set_cyan (GtkWidget *widget, gpointer data)
+{
+	GnomeCanvasItem *item;
+
+	item = GNOME_CANVAS_ITEM (data);
+
+	gnome_canvas_item_set (item,
+			       "fill_color", "cyan",
+			       NULL);
+}
+
+static void
+set_magenta (GtkWidget *widget, gpointer data)
+{
+	GnomeCanvasItem *item;
+
+	item = GNOME_CANVAS_ITEM (data);
+
+	gnome_canvas_item_set (item,
+			       "fill_color", "magenta",
+			       NULL);
+}
+
+static void
+set_yellow (GtkWidget *widget, gpointer data)
+{
+	GnomeCanvasItem *item;
+
+	item = GNOME_CANVAS_ITEM (data);
+
+	gnome_canvas_item_set (item,
+			       "fill_color", "yellow",
+			       NULL);
+}
+
+/* Explicit popup menu definition for the GnomeAppHelper test */
+
+
+static GnomeUIInfo helper_explicit_popup_dup[] = {
+	{ GNOME_APP_UI_ITEM, "Set color to _cyan", NULL, set_cyan, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Set color to _magenta", NULL, set_magenta, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Set color to _yellow", NULL, set_yellow, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo helper_explicit_popup[] = {
+	{ GNOME_APP_UI_ITEM, "Set color to _cyan", NULL, set_cyan, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Set color to _magenta", NULL, set_magenta, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, "Set color to _yellow", NULL, set_yellow, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+        GNOMEUIINFO_SUBTREE("Subtree", helper_explicit_popup_dup),
+	GNOMEUIINFO_END
+};
+
+/* Event handler for canvas items in the explicit popup menu demo */
+
+static gint
+item_event (GnomeCanvasItem *item, GdkEvent *event, gpointer data)
+{
+	if (!((event->type == GDK_BUTTON_PRESS) && (event->button.button == 3)))
+		return FALSE;
+
+	gnome_popup_menu_do_popup (GTK_WIDGET (data), NULL, NULL, (GdkEventButton *) event, item, NULL);
+
+	return TRUE;
+}
+
+static void
+delete_event (GtkWidget *widget, gpointer data)
+{
+	gtk_widget_destroy(data);
+}
+
+static void
+create_app_helper (GtkWidget *widget, gpointer data)
+{
+	GtkWidget *app;
+	GtkWidget *vbox;
+	GtkWidget *frame;
+	GtkWidget *vbox2;
+	GtkWidget *w;
+	GtkWidget *popup;
+        GnomeAppBar *bar;
+	GnomeCanvasItem *item;
+
+	app = gnome_app_new ("testGNOME", "GnomeAppHelper test");
+	gnome_app_create_menus (GNOME_APP (app), helper_main_menu);
+	gnome_app_create_toolbar (GNOME_APP (app), helper_toolbar);
+
+        bar = GNOME_APPBAR(gnome_appbar_new(FALSE, TRUE, GNOME_PREFERENCES_USER));
+        gnome_app_set_statusbar(GNOME_APP(app), GTK_WIDGET(bar));
+
+        gnome_app_install_appbar_menu_hints(GNOME_APPBAR(bar), helper_main_menu);
+
+	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
+
+	/* Shared popup menu */
+
+	popup = gnome_popup_menu_new (helper_shared_popup);
+
+	frame = gtk_frame_new ("Shared popup menu");
+	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+	gtk_widget_show (frame);
+
+	vbox2 = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox2), GNOME_PAD_SMALL);
+	gtk_container_add (GTK_CONTAINER (frame), vbox2);
+	gtk_widget_show (vbox2);
+
+	w = gtk_entry_new ();
+	gtk_box_pack_start (GTK_BOX (vbox2), w, FALSE, FALSE, 0);
+	gtk_widget_show (w);
+	gnome_popup_menu_attach (popup, w, w);
+	
+	w = gtk_entry_new ();
+	gtk_box_pack_start (GTK_BOX (vbox2), w, FALSE, FALSE, 0);
+	gtk_widget_show (w);
+	gnome_popup_menu_attach (popup, w, w);
+
+	/* Popup menu explicitly popped */
+
+	popup = gnome_popup_menu_new (helper_explicit_popup);
+
+	frame = gtk_frame_new ("Explicit popup menu");
+	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
+	gtk_widget_show (frame);
+
+	w = gnome_canvas_new ();
+	gtk_widget_set_size_request ((w), 200, 100);
+	gnome_canvas_set_scroll_region (GNOME_CANVAS (w), 0.0, 0.0, 200.0, 100.0);
+	gtk_container_add (GTK_CONTAINER (frame), w);
+	gtk_widget_show (w);
+
+	g_signal_connect (w, "destroy",
+			  G_CALLBACK (delete_event),
+			  popup);
+
+	item = gnome_canvas_item_new (gnome_canvas_root (GNOME_CANVAS (w)),
+				      gnome_canvas_ellipse_get_type (),
+				      "x1", 5.0,
+				      "y1", 5.0,
+				      "x2", 95.0,
+				      "y2", 95.0,
+				      "fill_color", "white",
+				      "outline_color", "black",
+				      NULL);
+	g_signal_connect (item, "event",
+			  G_CALLBACK (item_event),
+			  popup);
+
+	item = gnome_canvas_item_new (gnome_canvas_root (GNOME_CANVAS (w)),
+				      gnome_canvas_ellipse_get_type (),
+				      "x1", 105.0,
+				      "y1", 0.0,
+				      "x2", 195.0,
+				      "y2", 95.0,
+				      "fill_color", "white",
+				      "outline_color", "black",
+				      NULL);
+	g_signal_connect (item, "event",
+			  G_CALLBACK (item_event),
+			  popup);
+
+	gnome_app_set_contents (GNOME_APP (app), vbox);
+	gtk_widget_show (app);
+}
+
 /*
  * ImageEntry
  */
@@ -971,7 +1480,6 @@ create_unit_spinner (void)
 static void
 create_about_box (void)
 {
-	const char *authors[] = { "Author1", "Author2", "Author3", NULL };
 	const char *documentors[] = { "Documentor1", "Documentor2", NULL };
 	GtkWidget *about_box = gnome_about_new ("Test GNOME",
 						VERSION,
@@ -992,20 +1500,24 @@ main (int argc, char **argv)
 		void (*func) ();
 	} buttons[] =
 	  {
-		{ "color picker", create_color_picker },
-		{ "date edit", create_date_edit },
+		  { "app window", create_app_helper },
+		  { "color picker", create_color_picker },
+		  { "date edit", create_date_edit },
 /*		{ "ditem edit", create_ditem_edit },*/
 /*		{ "druid", create_druid }, */
-		{ "entry", create_entry },
-		{ "file entry", create_file_entry },
-/*		{ "font picker", create_font_picker },*/
-		{ "href", create_href },
-		{ "icon list", create_icon_list },
+		  { "entry", create_entry },
+		  { "file entry", create_file_entry },
+		  { "pixmap entry", create_pixmap_entry },
+		  { "icon entry", create_icon_entry },
+/*		{ "font selector", create_font_selector }, */
+		  { "font picker", create_font_picker },
+		  { "href", create_href },
+		  { "icon list", create_icon_list },
 /*		{ "image entry", create_image_entry }, */
 /*		{ "image selector", create_image_selector },*/
 /*		{ "paper selector", create_papersel },*/
 /*		{ "unit spinner", create_unit_spinner },*/
-		{ "about box", create_about_box }
+		  { "about box", create_about_box }
 	  };
 	int nbuttons = sizeof (buttons) / sizeof (buttons[0]);
 	TestGnomeApp *app;
@@ -1021,7 +1533,7 @@ main (int argc, char **argv)
 			    argc, argv, NULL);
 
 	app = create_newwin (FALSE, "testGNOME", "testGNOME");
-	gtk_widget_set_usize (app->app, 200, 300);
+	gtk_window_set_default_size (GTK_WINDOW (app->app), 200, 300);
 	box1 = gtk_vbox_new (FALSE, 0);
 	bonobo_window_set_contents (BONOBO_WINDOW (app->app), box1);
 	gtk_widget_show (box1);
@@ -1042,10 +1554,9 @@ main (int argc, char **argv)
 	for (i = 0; i < nbuttons; i++) {
 		button = gtk_button_new_with_label (buttons[i].label);
 		if (buttons[i].func)
-			gtk_signal_connect (GTK_OBJECT (button),
-					    "clicked",
-					    GTK_SIGNAL_FUNC(buttons[i].func),
-					    NULL);
+			g_signal_connect (button, "clicked",
+					  G_CALLBACK(buttons[i].func),
+					  NULL);
 		else
 			gtk_widget_set_sensitive (button, FALSE);
 		gtk_box_pack_start (GTK_BOX (box2), button, TRUE, TRUE, 0);
@@ -1054,8 +1565,7 @@ main (int argc, char **argv)
 
 	gtk_widget_show (app->app);
 
-	bonobo_main ();
+	gtk_main ();
 
 	return 0;
 }
-
